@@ -89,14 +89,18 @@ index_add_default_filters();
 /// Initialise.
 void
 index_init(const std::string & dbpath, const Xapian::Stem & stemmer,
-	   const std::string & root_, const std::string & site_term_,
-	   const std::string & host_term_,
+	   const std::string & root_,
+	   const std::string & site_term_, const std::string & host_term_,
 	   empty_body_type empty_body_, dup_action_type dup_action_,
-	   size_t sample_size_, size_t title_size_, size_t max_ext_len_,
+	   size_t sample_size_, size_t title_size_,
+	   size_t max_ext_len_,
 	   bool overwrite, bool retry_failed_,
 	   bool delete_removed_documents, bool verbose_, bool use_ctime_,
 	   bool spelling, bool ignore_exclusions_, bool description_as_sample);
 
+void
+index_remove_failed_entry(const std::string & urlterm);
+
 void
 index_add_document(const std::string & urlterm, time_t last_altered,
 		   Xapian::docid did, const Xapian::Document & doc);
