@@ -1,6 +1,7 @@
-/* md5wrap.h: wrapper functions to allow easy use of MD5 from C++.
- *
- * Copyright (C) 2006,2007,2010,2013 Olly Betts
+/** @file md5wrap.h
+ * @brief wrapper functions to allow easy use of MD5 from C++.
+ */
+/* Copyright (C) 2006,2007,2010,2013,2018 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,9 +23,11 @@
 
 #include <string>
 
-bool md5_file(const std::string &file_name, std::string &md5, bool try_noatime);
-void md5_block(const char * p, size_t len, std::string &md5);
-inline void md5_string(const std::string &str, std::string &md5) {
+bool md5_fd(int fd, std::string& md5);
+
+void md5_block(const char* p, size_t len, std::string& md5);
+
+inline void md5_string(const std::string& str, std::string& md5) {
     md5_block(str.data(), str.size(), md5);
 }
 
