@@ -428,7 +428,8 @@ main(int argc, char **argv)
 "BASEDIR is the directory corresponding to URL (default: DIRECTORY).\n"
 "\n"
 "Options:\n"
-"  -d, --duplicates          set duplicate handling ('ignore' or 'replace')\n"
+"  -d, --duplicates=ARG      set duplicate handling: ARG can be 'ignore' or\n"
+"                            'replace' (default: replace)\n"
 "  -p, --no-delete           skip the deletion of documents corresponding to\n"
 "                            deleted files (--preserve-nonduplicates is a\n"
 "                            deprecated alias for --no-delete)\n"
