@@ -24,6 +24,10 @@
 
 #include <ctime>
 
-char* strptime(const char* date_string, const char* format, struct std::tm* tm);
+char* strptime_using_std_get_time(const char* date_string,
+				  const char* format,
+				  struct std::tm* tm);
+
+#define strptime(D, F, TM) strptime_using_std_get_time(D, F, TM)
 
 #endif
