@@ -54,7 +54,7 @@ convert_to_utf8(string & text, const string & charset)
     char buf[1024];
     string tmp;
 
-    /* Handle iso-8859-1/windows-1252/cp-1252, utf-16/ucs-2,
+    /* Handle iso-8859-1/iso-8859-15//windows-1252/cp-1252, utf-16/ucs-2,
      * utf-16be/ucs-2be, and utf-16le/ucs-2le. */
     const char * p = charset.c_str();
 
@@ -164,7 +164,9 @@ convert_to_utf8(string & text, const string & charset)
 	    if (strncmp(p, "8859", 4) != 0) goto try_iconv;
 	    p += 4;
 	    if (*p == '-' || *p == '_' || *p == ' ') ++p;
-	    if (strcmp(p, "1") != 0) goto try_iconv;
+	    if (*p != '1') goto try_iconv;
+	    if (strcmp(p + 1, "5") == 0) goto iso8859_15;
+	    if (p[1] != '\0') goto try_iconv;
 	}
 
 	// FIXME: pull this out as a standard "normalise utf-8" function?
@@ -217,5 +219,31 @@ try_iconv:
 #endif
     }
 
+    if (false) {
+iso8859_15:
+	tmp.reserve(text.size());
+
+	size_t start = 0;
+	for (string::const_iterator i = text.begin(); i != text.end(); ++i) {
+	    static const unsigned iso8859_15_to_unicode[] = {
+		0x20ac, 0x00a5, 0x0160, 0x00a7, 0x0161, 0x00a9, 0x00aa, 0x00ab,
+		0x00ac, 0x00ad, 0x00ae, 0x00af, 0x00b0, 0x00b1, 0x00b2, 0x00b3,
+		0x017d, 0x00b5, 0x00b6, 0x00b7, 0x017e, 0x00b9, 0x00ba, 0x00bb,
+		0x0152, 0x0153, 0x0178
+	    };
+	    const size_t ISO8859_15_TO_UNICODE_ENTRIES =
+		sizeof(iso8859_15_to_unicode) / sizeof(*iso8859_15_to_unicode);
+	    unsigned ch = static_cast<unsigned char>(*i);
+	    if (ch - 164 < ISO8859_15_TO_UNICODE_ENTRIES)
+		ch = iso8859_15_to_unicode[ch - 164];
+	    start += Xapian::Unicode::to_utf8(ch, buf + start);
+	    if (start >= sizeof(buf) - 4) {
+		tmp.append(buf, start);
+		start = 0;
+	    }
+	}
+	if (start) tmp.append(buf, start);
+    }
+
     swap(text, tmp);
 }
